Examples
========

Various examples are located in the directory ``doc/examples/`` as Python
scripts, e.g.

* sound_field_synthesis.py:
    Illustrates the general usage of the toolbox
* horizontal_plane_arrays.py:
    Computes the sound fields for various techniques, virtual sources and loudspeaker array configurations
* soundfigures.py:
    Illustrates the synthesis of sound figures with Wave Field Synthesis


Or Jupyter notebooks, which are also available online as interactive examples:
:binder:`doc/examples`.


.. toctree::
    :maxdepth: 1

    modal-room-acoustics
